#[unsafe(no_mangle)]pub extern "C" fn cigar_to_string(
handle: *const CigarHandle,
) -> *mut c_charExpand description
Convert CIGAR vector to string Returns C string that must be freed with temp_file_free_string
#[unsafe(no_mangle)]pub extern "C" fn cigar_to_string(
handle: *const CigarHandle,
) -> *mut c_charConvert CIGAR vector to string Returns C string that must be freed with temp_file_free_string